@@ -27,13 +27,20 @@
 #include <string.h>
 #include <stdlib.h> // for 'system'
 #ifdef ENABLE_MP3
+#   include <id3tag.h>
+#   ifdef ENABLE_ID3LIB
 #   include <id3.h>
+#   endif
+#endif
+#ifdef ENABLE_FLAC
+#   include <FLAC/metadata.h>
 #endif
 #include <errno.h>
 
 #include "about.h"
 #include "easytag.h"
 #include "misc.h"
+#include "log.h"
 #include "msgbox.h"
 #include "charset.h"
 
@@ -43,6 +50,7 @@
 
 #ifdef WIN32
 #   include "win32/win32dep.h"
+#   include "win32/gtkwin32dep.h"
 #endif
 
 
@@ -51,6 +59,19 @@
  ****************/
 static GtkWidget *AboutWindow = NULL;
 
+// Columns for features supported...
+enum
+{
+    // Columns for titles
+    EXTENSION_PIXBUF = 0,
+    EXTENSION_NAME,
+    EXTENSION_STATUT,
+    EXTENSION_COMMENT,
+
+    EXTENSION_COLUMN_COUNT
+};
+
+
 
 /**************
  * Prototypes *
@@ -103,9 +124,10 @@ void Show_About_Window (void)
     GtkWidget *ScrollWindow;
     GtkWidget *TextView;
     GtkTextBuffer *TextBuffer;
-    GtkTextIter iter;
+    GtkTextIter textIter;
     GtkWidget *Button;
     GtkWidget *Logo;
+    //GdkPixbuf *pixbuf = NULL;
     GdkPixmap *pixmap;
     GdkBitmap *mask;
     gchar  temp[MAX_STRING_LEN];
@@ -122,7 +144,6 @@ void Show_About_Window (void)
             "simple and nice GTK+ interface makes tagging easier under GNU/Linux."
             "");
 
-
     /* Translation contributions */
     gchar *translations_thanks_text [][2]= {
             {"    - Bastian Kleineidam ",           _("(German translation)")},
@@ -132,12 +153,13 @@ void Show_About_Window (void)
             {"    - Sergey Zhumatiy ",              _("(Russian translation)")},
             {"    - Andrey Astafiev ",              _("(Russian translation)")},
             {"    - Vincent van Adrighem ",         _("(Dutch translation)")},
-            {"    - Bjrn Olievier ",               _("(Dutch translation)")},
+            {"    - Björn Olievier ",               _("(Dutch translation)")},
             {"    - Patrik Israelsson ",            _("(Swedish translation)")},
-            {"    - Anders Strmer ",               _("(Swedish translation)")},
+            {"    - Anders Strömer ",               _("(Swedish translation)")},
+            {"    - Arild Matsson ",                _("(Swedish translation)")},
             {"    - Szel Miklos ",                  _("(Hungarian translation)")},
             {"    - Nagy Boldizsar ",               _("(Hungarian translation)")},
-            {"    - Mszros Csaba ",               _("(Hungarian translation)")},
+            {"    - Mészáros Csaba ",               _("(Hungarian translation)")},
             {"    - Cappelletti Lorenzo ",          _("(Italian translation)")},
             {"    - Costantino Ceoldo ",            _("(Italian translation)")},
             {"    - Takeshi Aihana ",               _("(Japanese translation)")},
@@ -155,6 +177,10 @@ void Show_About_Window (void)
             {"    - doutor zero ",                  _("(Brazilian Portuguese translation)")},
             {"    - Luchezar P. Petkov ",           _("(Bulgarian translation)")},
             {"    - Yang Jinsong ",                 _("(Chinese translation)")},
+            {"    - Jose Sun ",                     _("(Chinese (Taiwan) translation)")},
+            {"    - Yuval Hager ",                  _("(Hebrew translation)")},
+            {"    - Miloš Popović ",                _("(Serbian translation)")},
+            {"    - Götz Waschk ",                  _("(German translation)")},
             {NULL,NULL}
             };
 
@@ -200,8 +226,23 @@ void Show_About_Window (void)
             "    - Der Humph\n"
             "    - Emmanuel Brun\n"
             "    - Maarten Maathuis\n"
+            "    - Pierre Dumuid\n"
+            "    - Kip Warner\n"
+            "    - Mark Ferry\n"
+            "    - Gaute Amundsen\n"
             "";
 
+    GtkWidget *ExtensionList;
+    GtkListStore *ExtensionListModel;
+    GtkTreeViewColumn* column;
+    GtkCellRenderer* renderer;
+    gchar *ExtensionList_Titles[] = { N_("Extension Name"),
+                                      N_("Status"),
+                                      N_("Comment")
+                                    };
+    GtkTreeIter treeIter;
+    //GError *error = NULL;
+    
 
     /* Check if already opened */
     if (AboutWindow)
@@ -248,7 +289,7 @@ void Show_About_Window (void)
 #else
     pixmap = gdk_pixmap_create_from_xpm_d(AboutWindow->window,&mask,NULL,EasyTAG_logo_xpm);
 #endif
-
+    
     if (pixmap)
     {
         Logo = gtk_image_new_from_pixmap(pixmap, mask);
@@ -257,6 +298,21 @@ void Show_About_Window (void)
         gtk_box_pack_start(GTK_BOX(VBox),Logo,FALSE,TRUE,0);
         gtk_misc_set_padding(GTK_MISC(Logo),2,2);
     }
+/*#ifdef PACKAGE_DATA_DIR
+    pixbuf = gdk_pixbuf_new_from_file(PACKAGE_DATA_DIR"/EasyTAG_logo.png",&error);
+#endif
+    
+    if (pixbuf)
+    {
+        Logo = gtk_image_new_from_pixbuf(pixbuf);
+        g_object_unref(pixbuf);
+        gtk_box_pack_start(GTK_BOX(VBox),Logo,FALSE,TRUE,0);
+        gtk_misc_set_padding(GTK_MISC(Logo),2,2);
+    }else
+    {
+        Log_Print(LOG_ERROR,error->message);
+        g_error_free(error);
+    }*/
 
     /* Infos */
     Label = gtk_label_new(NULL);
@@ -267,32 +323,9 @@ void Show_About_Window (void)
     Label = gtk_label_new(temp);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 
-#ifdef ENABLE_MP3 // FIX ME : should separate gtk and id3lib
-    sprintf(temp,_("(using: GTK+ %d.%d.%d and id3lib %d.%d.%d)"),GTK_MAJOR_VERSION,GTK_MINOR_VERSION,
-        GTK_MICRO_VERSION,ID3LIB_MAJOR_VERSION,ID3LIB_MINOR_VERSION,ID3LIB_PATCH_VERSION);
+    sprintf(temp,_("(using: GTK+ %d.%d.%d)"),GTK_MAJOR_VERSION,GTK_MINOR_VERSION,GTK_MICRO_VERSION);
     Label = gtk_label_new(temp);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
-#endif
-
-#ifndef ENABLE_MP3
-    Label = gtk_label_new(_("(MP3 file support disabled)"));
-    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
-#endif
-
-#ifndef ENABLE_OGG
-    Label = gtk_label_new(_("(Ogg Vorbis file support disabled)"));
-    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
-#endif
-
-#ifndef ENABLE_FLAC
-    Label = gtk_label_new(_("(FLAC file support disabled)"));
-    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
-#endif
-
-#ifndef ENABLE_MP4
-    Label = gtk_label_new(_("(MP4/AAC file support disabled)"));
-    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
-#endif
 
     /* Insert a blank line */
     Label = gtk_label_new("");
@@ -312,6 +345,7 @@ void Show_About_Window (void)
     gtk_misc_set_alignment(GTK_MISC(Label),1,0.5);
     gtk_box_pack_start(GTK_BOX(hbox),Label,TRUE,TRUE,0);
     Button = gtk_button_new_with_label(WEBPAGE);
+    //Button = gtk_link_button_new(WEBPAGE);
     gtk_box_pack_start(GTK_BOX(hbox),Button,TRUE,TRUE,0);
     g_signal_connect(G_OBJECT(Button),"clicked", G_CALLBACK(About_Window_Go_To_Home_Page),NULL);
     gtk_button_set_relief(GTK_BUTTON(Button),GTK_RELIEF_NONE);
@@ -324,20 +358,185 @@ void Show_About_Window (void)
     gtk_frame_set_shadow_type(GTK_FRAME(Frame),GTK_SHADOW_IN);
     gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,TRUE,0);
     gtk_container_set_border_width(GTK_CONTAINER(Frame), 2);
-
+    
     Label = gtk_label_new(_(description_text));
     gtk_misc_set_padding(GTK_MISC(Label),2,2);
     gtk_label_set_line_wrap(GTK_LABEL(Label),TRUE);
     gtk_container_add(GTK_CONTAINER(Frame),Label);
 
 
+
+    /*
+     * Tab for extensions
+     */
+
+    Label = gtk_label_new(_("Extensions"));
+    Frame = gtk_frame_new(NULL);
+    gtk_notebook_append_page(GTK_NOTEBOOK(AboutNoteBook),Frame,Label);
+
+    ScrollWindow = gtk_scrolled_window_new(NULL,NULL);
+    gtk_container_add(GTK_CONTAINER(Frame),ScrollWindow);
+    gtk_container_set_border_width(GTK_CONTAINER(Frame),2);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ScrollWindow),
+                                   GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
+
+    ExtensionListModel = gtk_list_store_new(EXTENSION_COLUMN_COUNT,
+                                            G_TYPE_STRING,      /* Pixbuf, but we use the Stock ID, so don't use GDK_TYPE_PIXBUF */
+                                            G_TYPE_STRING,      /* Extension name */
+                                            G_TYPE_STRING,      /* Statut */
+                                            G_TYPE_STRING       /* Comment */
+                                            );
+    ExtensionList = gtk_tree_view_new_with_model(GTK_TREE_MODEL(ExtensionListModel));
+
+    /* Pixbuf and Extension name */
+    column = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_title(column, _(ExtensionList_Titles[0]));
+
+    // Cell of the column for the pixbuf
+    renderer = gtk_cell_renderer_pixbuf_new();
+    gtk_tree_view_column_pack_start(column, renderer, FALSE);
+    gtk_tree_view_column_set_attributes(column, renderer,
+                                       "stock-id", EXTENSION_PIXBUF,
+                                        NULL);
+    // Cell of the column for the text
+    renderer = gtk_cell_renderer_text_new();
+    gtk_tree_view_column_pack_start(column, renderer, FALSE);
+    gtk_tree_view_column_set_attributes(column, renderer,
+                                       "text", EXTENSION_NAME,
+                                        NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(ExtensionList), column);
+    gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+
+    /* Statut */
+    renderer = gtk_cell_renderer_text_new();
+    column = gtk_tree_view_column_new_with_attributes(_(ExtensionList_Titles[1]), renderer,
+                                                      "text", EXTENSION_STATUT,
+                                                      NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(ExtensionList), column);
+    gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+
+    /* Comment */
+    renderer = gtk_cell_renderer_text_new();
+    column = gtk_tree_view_column_new_with_attributes(_(ExtensionList_Titles[2]), renderer,
+                                                      "text", EXTENSION_COMMENT,
+                                                      NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(ExtensionList), column);
+    gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+
+    gtk_container_add(GTK_CONTAINER(ScrollWindow),ExtensionList);
+    gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(ExtensionList)),
+            GTK_SELECTION_NONE);
+    gtk_tree_view_set_headers_clickable(GTK_TREE_VIEW(ExtensionList), FALSE);
+    
+
+    // Load extensions list
+    // MP3
+#ifdef ENABLE_MP3
+    sprintf(temp, "libid3tag %s", ID3_VERSION);
+#endif
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("MP3 file support"),
+#ifdef ENABLE_MP3
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("enabled"),
+                       EXTENSION_COMMENT,   temp,
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+#ifdef ENABLE_MP3
+#if (defined ENABLE_ID3LIB) 
+    sprintf(temp, "id3lib %d.%d.%d", ID3LIB_MAJOR_VERSION, ID3LIB_MINOR_VERSION, ID3LIB_PATCH_VERSION);
+#endif
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("ID3v2.3 tags writting support"),
+#if (defined ENABLE_ID3LIB) 
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("available"), // May not be used
+                       EXTENSION_COMMENT,   temp,
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+#endif
+    // Ogg Vorbis
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("Ogg Vorbis file support"),
+#ifdef ENABLE_OGG
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("enabled"),
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+    // Speex
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("Speex file support"),
+#ifdef ENABLE_SPEEX
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("enabled"),
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+    // FLAC
+#ifdef ENABLE_FLAC
+    sprintf(temp, "flac %s", FLAC__VERSION_STRING);
+#endif
+
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("FLAC file support"),
+#ifdef ENABLE_FLAC
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("enabled"),
+                       EXTENSION_COMMENT,   temp,
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+    // MP4
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("MP4/AAC file support"),
+#ifdef ENABLE_MP4
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("enabled"),
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+    // WavPack
+    gtk_list_store_append(ExtensionListModel, &treeIter);
+    gtk_list_store_set(ExtensionListModel, &treeIter,
+                       EXTENSION_NAME,      _("WavPack file support"),
+#ifdef ENABLE_WAVPACK
+                       EXTENSION_PIXBUF,    GTK_STOCK_APPLY,
+                       EXTENSION_STATUT,    _("enabled"),
+#else
+                       EXTENSION_PIXBUF,    GTK_STOCK_CANCEL,
+                       EXTENSION_STATUT,    _("disabled"),
+#endif
+                       -1);
+
+
     /*
      * Tab for thanks
      */
 
     Label = gtk_label_new(_("Thanks"));
     Frame = gtk_frame_new(NULL);
-    gtk_notebook_append_page (GTK_NOTEBOOK(AboutNoteBook),Frame,Label);
+    gtk_notebook_append_page(GTK_NOTEBOOK(AboutNoteBook),Frame,Label);
 
     ScrollWindow = gtk_scrolled_window_new(NULL,NULL);
     gtk_container_add(GTK_CONTAINER(Frame),ScrollWindow);
@@ -353,41 +552,43 @@ void Show_About_Window (void)
     //gtk_text_buffer_create_tag(TextBuffer, "x-large", "scale", PANGO_SCALE_X_LARGE, NULL);
     //gtk_text_buffer_create_tag(TextBuffer, "monospace", "family", "monospace", NULL);
 
-    gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
+    gtk_text_buffer_get_iter_at_offset(TextBuffer, &textIter, 0);
 
     temp_str = _("Translations:\n");
-    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                              temp_str, -1,
                                              "bold", "underline", "large", NULL);
 
     for (i=0; translations_thanks_text[i][0]!=NULL; i++)
     {
         // Translator name
-        if (!g_utf8_validate(translations_thanks_text[i][0], -1, NULL))
+        /*if (!g_utf8_validate(translations_thanks_text[i][0], -1, NULL))
             temp_str = convert_string(translations_thanks_text[i][0], "iso-8859-1", "utf-8",TRUE);
         else
-            temp_str = g_strdup(translations_thanks_text[i][0]);
-        gtk_text_buffer_insert(TextBuffer, &iter, temp_str, -1);
+            temp_str = g_strdup(translations_thanks_text[i][0]);*/
+        temp_str = Try_To_Validate_Utf8_String(translations_thanks_text[i][0]);
+        gtk_text_buffer_insert(TextBuffer, &textIter, temp_str, -1);
         g_free(temp_str);
 
         // Translation language
-        if (!g_utf8_validate(translations_thanks_text[i][1], -1, NULL))
+        /*if (!g_utf8_validate(translations_thanks_text[i][1], -1, NULL))
             temp_str = convert_string(translations_thanks_text[i][1], "iso-8859-1", "utf-8",TRUE);
         else
-            temp_str = g_strdup(translations_thanks_text[i][1]);
-        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, temp_str, -1,
+            temp_str = g_strdup(translations_thanks_text[i][1]);*/
+        temp_str = Try_To_Validate_Utf8_String(translations_thanks_text[i][1]);
+        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter, temp_str, -1,
                                                  "italic", NULL);
         g_free(temp_str);
-        gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
+        gtk_text_buffer_insert(TextBuffer, &textIter, "\n", -1);
     }
 
-    gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
+    gtk_text_buffer_insert(TextBuffer, &textIter, "\n", -1);
 
     temp_str = _("General:\n");
-    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                              temp_str, -1,
                                              "bold", "underline", "large", NULL);
-    gtk_text_buffer_insert(TextBuffer, &iter, general_thanks_text, -1);
+    gtk_text_buffer_insert(TextBuffer, &textIter, general_thanks_text, -1);
 
     TextView = gtk_text_view_new_with_buffer(TextBuffer);
     gtk_container_add(GTK_CONTAINER(ScrollWindow),TextView);
@@ -411,19 +612,19 @@ void Show_About_Window (void)
                                    GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 
     TextBuffer = gtk_text_buffer_new(NULL);
-    gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
+    gtk_text_buffer_get_iter_at_offset(TextBuffer, &textIter, 0);
     gtk_text_buffer_create_tag(TextBuffer, "monospace", "family", "monospace", NULL);
     gtk_text_buffer_create_tag(TextBuffer, "red_foreground", "foreground", "red", NULL);
     gtk_text_buffer_create_tag(TextBuffer, "blue_foreground", "foreground", "blue", NULL);
     gtk_text_buffer_create_tag(TextBuffer, "bold", "weight", PANGO_WEIGHT_BOLD, NULL);
 
-    gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
+    gtk_text_buffer_get_iter_at_offset(TextBuffer, &textIter, 0);
 
     // The file 'ChangeLog' to read
     if ( (file=fopen(PACKAGE_DATA_DIR"/ChangeLog","r"))==0 )
     {
         gchar *msg = g_strdup_printf(_("Can't open file '%s' (%s)\n"),PACKAGE_DATA_DIR"/ChangeLog",g_strerror(errno));
-        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                                  msg, -1,
                                                  "monospace", "red_foreground", NULL);
         g_free(msg);
@@ -431,42 +632,45 @@ void Show_About_Window (void)
     {
         gint first_version = 0;
 
-        while(fgets(temp,sizeof(temp),file))
+        while (fgets(temp,sizeof(temp),file))
         {
             if (temp[strlen(temp)-1]=='\n')
                 temp[strlen(temp)-1]='\0';
             if (temp[strlen(temp)-1]=='\r')
                 temp[strlen(temp)-1]='\0';
 
-            if (!g_utf8_validate(temp, -1, NULL))
+            // Convert line to UTF-8
+            /*if (!g_utf8_validate(temp, -1, NULL))
                 tmp = convert_string(temp, "iso-8859-1", "utf-8",TRUE);
             else
-                tmp = g_strdup(temp);
+                tmp = g_strdup(temp);*/
+            tmp = Try_To_Validate_Utf8_String(temp);
 
-            if (tmp && tmp[0]!=' ')
+            if (tmp && tmp[0]!=' ') // If first character is a space => 1rst line after title
             {
                 first_version++;
                 // To set to bold the title of the version and to red the first version
                 if (first_version > 2) // As title takes 2 lines
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                                              tmp, -1,
                                                              "monospace", "bold", NULL);
                 else
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                                              tmp, -1,
                                                              "monospace", "bold", "blue_foreground", NULL);
             }else
             {
                 if (first_version > 2) // As title takes 2 lines
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                                              tmp, -1,
                                                              "monospace", NULL);
                 else
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &textIter,
                                                              tmp, -1,
                                                              "monospace", "blue_foreground", NULL);
             }
-            gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
+
+            gtk_text_buffer_insert(TextBuffer, &textIter, "\n", -1);
             g_free(tmp);
         }
         fclose(file);
@@ -481,25 +685,26 @@ void Show_About_Window (void)
     /*
      * Close Button
      */
-    Button = Create_Button_With_Pixmap(BUTTON_CLOSE);
+    Button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(AboutWindow)->action_area),Button,FALSE,FALSE,0);
     g_signal_connect(G_OBJECT(Button),"clicked", G_CALLBACK(Quit_About_Window),NULL);
     GTK_WIDGET_SET_FLAGS(Button,GTK_CAN_DEFAULT);
     gtk_widget_grab_default(Button);
 
 
-    /* Disable main window */
-    /*gtk_widget_set_sensitive(MainWindow,FALSE);*/
-
     gtk_widget_show_all(AboutWindow);
+    //gtk_container_resize_children(GTK_CONTAINER(AboutNoteBook));
+
 }
 
 
 void About_Window_Go_To_Home_Page (void)
 {
 #ifdef WIN32
-    ET_Win32_Notify_Uri(WEBPAGE);
+    wineasytag_notify_uri(WEBPAGE);
 #else
-    system("gnome-moz-remote "WEBPAGE);
+    if (system("gnome-moz-remote "WEBPAGE)!=0)
+        if (system("x-www-browser "WEBPAGE)!=0)
+            system("www-browser "WEBPAGE);
 #endif
 }
