@@ -31,7 +31,7 @@
 
 #define APPNAME            "EasyTAG"
 #define AUTHOR             "Jerome Couderc"    // Note: do not use accents
-#define EMAIL              "easytag@gmail.com"
+#define EMAIL              "easytag-mailing@lists.sourceforge.net"
 #define WEBPAGE            "http://easytag.sourceforge.net"
 /*#define VERSION "0.15.1" //Now version is defined in ../configure.h.in */
 
@@ -88,6 +88,7 @@ GtkWidget    *TagFrame;
 GtkWidget    *TagNoteBook;
 GtkWidget    *TitleEntry;
 GtkWidget    *ArtistEntry;
+GtkWidget    *AlbumArtistEntry;
 GtkWidget    *AlbumEntry;
 GtkWidget    *DiscNumberEntry;
 GtkWidget    *YearEntry;
@@ -108,6 +109,7 @@ GtkListStore *PictureEntryModel;
 // Labels
 GtkWidget    *TitleLabel;
 GtkWidget    *ArtistLabel;
+GtkWidget    *AlbumArtistLabel;
 GtkWidget    *AlbumLabel;
 GtkWidget    *DiscNumberLabel;
 GtkWidget    *YearLabel;
@@ -123,6 +125,7 @@ GtkWidget    *PictureLabel;
 // Mini buttons
 GtkWidget    *TitleMButton;
 GtkWidget    *ArtistMButton;
+GtkWidget    *AlbumArtistMButton;
 GtkWidget    *AlbumMButton;
 GtkWidget    *DiscNumberMButton;
 GtkWidget    *YearMButton;
@@ -192,7 +195,7 @@ void File_Area_Set_Sensitive (gboolean activate);
 void Tag_Area_Set_Sensitive  (gboolean activate);
 void Tag_Area_Display_Controls (ET_File *ETFile);
 
-void Read_Directory                   (gchar *path);
+gboolean Read_Directory               (gchar *path);
 void Quit_MainWindow                  (void);
 void MainWindow_Apply_Changes         (void);
 void Update_Command_Buttons_Sensivity (void);
