@@ -220,6 +220,12 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if ( (frame = id3_tag_findframe(tag, ID3_FRAME_ARTIST, 0)) )
         update |= libid3tag_Get_Frame_Str(frame, EASYTAG_ID3_FIELD_STRINGLIST, &FileTag->artist);
 
+    /*****************
+     * Album Artist (TPE2) *
+     *****************/
+    if ( (frame = id3_tag_findframe(tag, "TPE2", 0)) )
+        update |= libid3tag_Get_Frame_Str(frame, EASYTAG_ID3_FIELD_STRINGLIST, &FileTag->album_artist);
+
     /****************
      * Album (TALB) *
      ****************/
@@ -871,6 +877,11 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
      **********/
     etag_set_tags(FileTag->artist, ID3_FRAME_ARTIST, ID3_FIELD_TYPE_STRINGLIST, v1tag, v2tag, &strip_tags);
 
+    /**********
+     * Album Artist *
+     **********/
+    etag_set_tags(FileTag->album_artist, "TPE2", ID3_FIELD_TYPE_STRINGLIST, NULL, v2tag, &strip_tags);
+
     /*********
      * Album *
      *********/
@@ -910,7 +921,7 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
     if (FileTag->genre)
         genre_value = Id3tag_String_To_Genre(FileTag->genre);
 
-    if (genre_value == ID3_INVALID_GENRE)
+    if ((genre_value == ID3_INVALID_GENRE)||(FILE_WRITING_ID3V2_TEXT_ONLY_GENRE))
         string1 = g_strdup(FileTag->genre);
     else
         string1 = g_strdup_printf("%d",genre_value);
