@@ -1,7 +1,7 @@
 /* misc.h - 2000/06/28 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,8 +30,9 @@
 
 GtkWidget *WritePlaylistWindow;
 GtkWidget *playlist_use_mask_name;
-GtkWidget *PlayListNameEntry;
+GtkWidget *PlayListNameMaskCombo;
 GtkWidget *playlist_use_dir_name;
+GtkWidget *playlist_only_selected_files;
 GtkWidget *playlist_full_path;
 GtkWidget *playlist_relative_path;
 GtkWidget *playlist_create_in_parent_dir;
@@ -39,55 +40,45 @@ GtkWidget *playlist_use_dos_separator;
 GtkWidget *playlist_content_none;
 GtkWidget *playlist_content_filename;
 GtkWidget *playlist_content_mask;
-GtkWidget *PlayListContentMaskEntry;
+GtkWidget *PlayListContentMaskCombo;
+GtkListStore *PlayListNameMaskModel;
+GtkListStore *PlayListContentMaskModel;
 
 GtkWidget *LoadFilenameWindow;
 GtkWidget *LoadFileRunScanner;
 
 
-/*
- * Types for using Audio Player
- */
-typedef enum
-{
-    PLAY_DIRECTORY = 0, // Load files of the directory
-    PLAY_SELECTION = 1,  // Load only selected file
-    PLAY_UNKNOWN
-} AP_Play_Type;
-
-
 
 /**************
  * Prototypes *
  **************/
 
 /*
- * Create Pixmaps, buttons,...
+ * Create Pixmaps, buttons...
  */
-GtkWidget *Create_Button_With_Pixmap         (guint button_type);
-GtkWidget *Create_Pixmap_Icon                (gchar **pixmap_name);
-GtkWidget *Create_Pixmap_Icon_With_Event_Box (gchar **pixmap_name);
-GtkWidget *Create_Button_With_Icon_And_Label (gchar **pixmap_name, gchar *label);
+GtkWidget *Create_Pixmap_Icon_With_Event_Box (const gchar *pixmap_name);
+GtkWidget *Create_Button_With_Icon_And_Label (const gchar *pixmap_name, gchar *label);
+GtkWidget *Create_Xpm_Image                  (const char **xpm_name);
 
 
 /*
- * Combobox history
+ * Combobox misc functions
  */
-void   Add_To_Combo_Box_History (GtkObject *combobox);
-GList *Add_String_To_Glist      (GList *list, gchar *string);
+gboolean Add_String_To_Combo_List(GtkListStore *liststore, gchar *string);
+gchar   *Get_Active_Combo_Box_Item(GtkComboBox *combo);
 
 
 /*
  * Other
  */
-void Entry_Changed_Disable_Object(GtkObject *widget_to_disable, GtkEditable *source_widget);
+void Entry_Changed_Disable_Object (GtkObject *widget_to_disable, GtkEditable *source_widget);
 void Insert_Only_Digit (GtkEditable *editable,const gchar *text,gint length,gint *position,gpointer data);
-void Parse_Genre (GtkEntry *entry, GdkEvent *event, GtkCombo *combo);
-void Parse_Date (void);
+gboolean Parse_Date (void);
 void Load_Genres_List_To_UI (void);
 void Load_Track_List_To_UI  (void);
 void Init_Character_Translation_Table (void);
-void Focus_Select_Text_In_Editable (GtkWidget *widget);
+void Init_Custom_Icons (void);
+gchar *Check_If_Executable_Exists (const gchar *program);
 
 // Mouse cursor
 void Init_Mouse_Cursor    (void);
@@ -95,14 +86,12 @@ void Destroy_Mouse_Cursor (void);
 void Set_Busy_Cursor      (void);
 void Set_Unbusy_Cursor    (void);
 
-// Tooltips
-GtkTooltips *gtk_tooltips_new_1 (void);
-void Set_Tips_Color (GtkTooltips *tips);
-
 // Run Audio Player
-void Run_Audio_Player_Using_File_List (AP_Play_Type type);
+void Run_Audio_Player_Using_File_List (GList *etfilelist);
 void Run_Audio_Player_Using_Directory (void);
 void Run_Audio_Player_Using_Selection (void);
+void Run_Audio_Player_Using_Browser_Artist_List (void);
+void Run_Audio_Player_Using_Browser_Album_List  (void);
 
 gchar *Convert_Size     (gfloat size);
 gchar *Convert_Size_1   (gfloat size);
@@ -111,16 +100,22 @@ gchar *Convert_Duration (gulong duration);
 gulong Get_File_Size (gchar *filename);
 
 void Strip_String (gchar *string);
+gint Combo_Alphabetic_Sort (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data);
 
-gchar *gtk_entry_get_text_1 (GtkWidget *widget);
-void   gtk_entry_set_text_1 (GtkWidget *widget, gchar *text);
+void File_Selection_Window_For_File      (GtkWidget *entry);
+void File_Selection_Window_For_Directory (GtkWidget *entry);
 
 // Playlist window
-void Open_Write_Playlist_Window (void);
+void Open_Write_Playlist_Window          (void);
+void Write_Playlist_Window_Apply_Changes (void);
+
 // Search file window
 void Open_Search_File_Window (void);
+void Search_File_Window_Apply_Changes (void);
+
 // Load filenames window
-void Open_Load_Filename_Window (void);
+void Open_Load_Filename_Window          (void);
+void Load_Filename_Window_Apply_Changes (void);
 
 
 #endif /* __MISC_H__ */
