@@ -89,26 +89,37 @@ gint    FILENAME_EXTENSION_LOWER_CASE;
 gint    FILENAME_EXTENSION_UPPER_CASE;
 gint    FILENAME_EXTENSION_NO_CHANGE;
 gint    PRESERVE_MODIFICATION_TIME;
+gint    UPDATE_PARENT_DIRECTORY_MODIFICATION_TIME;
 
 gint    FILENAME_CHARACTER_SET_OTHER;
 gint    FILENAME_CHARACTER_SET_APPROXIMATE;
 gint    FILENAME_CHARACTER_SET_DISCARD;
 
 /* Tag Settings */
-gint    WRITE_ID3V1_TAG;
-gint    WRITE_ID3V2_TAG;
 gint    WRITE_ID3_TAGS_IN_FLAC_FILE;
-gint    USE_ID3V2_PADDING;
 gint    STRIP_TAG_WHEN_EMPTY_FIELDS;
 gint    CONVERT_OLD_ID3V2_TAG_VERSION;
 
-gint    USE_ID3_ISO_8859_1_CHARACTER_SET;
-gint    USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET;
-gint    USE_ID3_UNICODE_CHARACTER_SET;
+gint    FILE_WRITING_ID3V2_VERSION_4;
 gint    USE_NON_STANDARD_ID3_READING_CHARACTER_SET;
-gint    USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET;
-gchar  *ID3_FILE_READING_CHARACTER_SET;
-gchar  *ID3_FILE_WRITING_CHARACTER_SET;
+gchar  *FILE_READING_ID3V1V2_CHARACTER_SET;
+
+gint    FILE_WRITING_ID3V2_WRITE_TAG;
+gint    FILE_WRITING_ID3V2_USE_CRC32;
+gint    FILE_WRITING_ID3V2_USE_COMPRESSION;
+gint    FILE_WRITING_ID3V2_TEXT_ONLY_GENRE;
+gint    FILE_WRITING_ID3V2_USE_UNICODE_CHARACTER_SET;
+gchar  *FILE_WRITING_ID3V2_UNICODE_CHARACTER_SET;
+gchar  *FILE_WRITING_ID3V2_NO_UNICODE_CHARACTER_SET;
+gint    FILE_WRITING_ID3V2_ICONV_OPTIONS_NO;
+gint    FILE_WRITING_ID3V2_ICONV_OPTIONS_TRANSLIT;
+gint    FILE_WRITING_ID3V2_ICONV_OPTIONS_IGNORE;
+
+gint    FILE_WRITING_ID3V1_WRITE_TAG;
+gchar  *FILE_WRITING_ID3V1_CHARACTER_SET;
+gint    FILE_WRITING_ID3V1_ICONV_OPTIONS_NO;
+gint    FILE_WRITING_ID3V1_ICONV_OPTIONS_TRANSLIT;
+gint    FILE_WRITING_ID3V1_ICONV_OPTIONS_IGNORE;
 
 gint    DATE_AUTO_COMPLETION;
 gint    NUMBER_TRACK_FORMATED;
@@ -116,10 +127,8 @@ gint    NUMBER_TRACK_FORMATED_SPIN_BUTTON;
 gint    OGG_TAG_WRITE_XMMS_COMMENT;
 gint    SET_FOCUS_TO_SAME_TAG_FIELD;
 gint    SET_FOCUS_TO_FIRST_TAG_FIELD;
-
-gint    FILE_WRITING_CHARACTER_SET_OTHER;
-gint    FILE_WRITING_CHARACTER_SET_APPROXIMATE;
-gint    FILE_WRITING_CHARACTER_SET_DISCARD;
+gint    LOG_MAX_LINES;
+gint    SHOW_LOG_VIEW;
 
 
 /* Scanner */
@@ -133,7 +142,7 @@ gint    RFS_CONVERT_SPACE_INTO_UNDERSCORE;
 gint    PFS_DONT_UPPER_SOME_WORDS;
 gint    OVERWRITE_TAG_FIELD;
 gint    SET_DEFAULT_COMMENT;
-gchar   *DEFAULT_COMMENT;
+gchar  *DEFAULT_COMMENT;
 gint    SET_CRC32_COMMENT;
 gint    OPEN_SCANNER_WINDOW_ON_STARTUP;
 gint    SCANNER_WINDOW_ON_TOP;
@@ -147,11 +156,13 @@ gint    CONFIRM_WRITE_TAG;
 gint    CONFIRM_RENAME_FILE;
 gint    CONFIRM_WRITE_PLAYLIST;
 gint    CONFIRM_DELETE_FILE;
+gint    CONFIRM_WHEN_UNSAVED_FILES;
 
 /* Scanner window */
 gint    PROCESS_FILENAME_FIELD;
 gint    PROCESS_TITLE_FIELD;
 gint    PROCESS_ARTIST_FIELD;
+gint    PROCESS_ALBUM_ARTIST_FIELD;
 gint    PROCESS_ALBUM_FIELD;
 gint    PROCESS_GENRE_FIELD;
 gint    PROCESS_COMMENT_FIELD;
@@ -160,6 +171,8 @@ gint    PROCESS_ORIG_ARTIST_FIELD;
 gint    PROCESS_COPYRIGHT_FIELD;
 gint    PROCESS_URL_FIELD;
 gint    PROCESS_ENCODED_BY_FIELD;
+gchar  *PROCESS_FIELDS_CONVERT_FROM;
+gchar  *PROCESS_FIELDS_CONVERT_TO;
 gint    PF_CONVERT_INTO_SPACE;
 gint    PF_CONVERT_SPACE;
 gint    PF_CONVERT;
@@ -167,6 +180,7 @@ gint    PF_CONVERT_ALL_UPPERCASE;
 gint    PF_CONVERT_ALL_DOWNCASE;
 gint    PF_CONVERT_FIRST_LETTER_UPPERCASE;
 gint    PF_CONVERT_FIRST_LETTERS_UPPERCASE;
+gint    PF_DETECT_ROMAN_NUMERALS;
 gint    PF_REMOVE_SPACE;
 gint    PF_INSERT_SPACE;
 gint    PF_ONLY_ONE_SPACE;
